pub async fn get_feature_sku(
    configuration: &Configuration,
    marketplace_id: &str,
    feature_name: &str,
    seller_sku: &str
) -> Result<GetFeatureSkuResponse, Error>
Returns the number of items with the sellerSKU you specify that can have orders fulfilled using the specified feature. Note that if the sellerSKU isn’t eligible, the response will contain an empty skuInfo object. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.