pub async fn get_features(
    configuration: &Configuration,
    marketplace_id: &str
) -> Result<GetFeaturesResponse, Error>
Returns a list of features available for Multi-Channel Fulfillment orders in the marketplace you specify, and whether the seller for which you made the call is enrolled for each feature. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.